@@ -5,7 +5,7 @@ from dataclasses import dataclass
 class Config:
     client_secret: str = None
 
-    log_loc: str = "logs"
+    log_loc: str = None
     promt: bool = True
     auth_host: str = "https://auth.dev.origen.ai"
     api_host: str = "https://proteus-test.dev.origen.ai"
@@ -15,3 +15,4 @@ class Config:
     client_id: str = "proteus-front"
     refresh_gap: int = 10  # Seconds
     ignore_worker_status: bool = False
+    upload_presigned: bool = True
